==> ali-qianniu-domain-0.1.32-sources.jar: com/xforceplus/ultraman/app/aliqianniu/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.aliqianniu.metadata;

/**
 *
 * @author ultraman
 * @since 2024-01-12
 */

public class PageMeta {
    public interface UnPushOrder {
        static String code() {
            return "unPushOrder";
        }
        static String name() {
            return "未推送订单页";
        }
    }
    public interface Spu {
        static String code() {
            return "spu";
        }
        static String name() {
            return "商品";
        }
    }
    public interface TaxNumber {
        static String code() {
            return "taxNumber";
        }
        static String name() {
            return "税编";
        }
    }
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票";
        }
    }
    public interface Bill {
        static String code() {
            return "bill";
        }
        static String name() {
            return "单据";
        }
    }
    public interface OrderPaid {
        static String code() {
            return "orderPaid";
        }
        static String name() {
            return "千牛商户支付订单";
        }
    }
    public interface UserTenant {
        static String code() {
            return "userTenant";
        }
        static String name() {
            return "渠道店铺信息";
        }
    }
    public interface InvoiceApply {
        static String code() {
            return "invoiceApply";
        }
        static String name() {
            return "开票申请";
        }
    }
    public interface Setting {
        static String code() {
            return "setting";
        }
        static String name() {
            return "设置";
        }
    }
}

==> ali-qianniu-domain-0.1.85-sources.jar: com/xforceplus/ultraman/app/aliqianniu/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.aliqianniu.metadata;

/**
 *
 * @author ultraman
 * @since 2024-04-02
 */

public class PageMeta {
    public interface UnPushOrder {
        static String code() {
            return "unPushOrder";
        }
        static String name() {
            return "未推送订单页";
        }
    }
    public interface Spu {
        static String code() {
            return "spu";
        }
        static String name() {
            return "商品";
        }
    }
    public interface TaxNumber {
        static String code() {
            return "taxNumber";
        }
        static String name() {
            return "税编";
        }
    }
    public interface UserTenant {
        static String code() {
            return "userTenant";
        }
        static String name() {
            return "渠道店铺信息";
        }
    }
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票";
        }
    }
    public interface ChannelConfig {
        static String code() {
            return "channelConfig";
        }
        static String name() {
            return "渠道信息配置页";
        }
    }
    public interface AbnormalBill {
        static String code() {
            return "abnormalBill";
        }
        static String name() {
            return "异常票据";
        }
    }
    public interface Setting {
        static String code() {
            return "setting";
        }
        static String name() {
            return "设置";
        }
    }
    public interface InvoiceApply {
        static String code() {
            return "invoiceApply";
        }
        static String name() {
            return "开票申请";
        }
    }
    public interface Bill {
        static String code() {
            return "bill";
        }
        static String name() {
            return "单据";
        }
    }
    public interface OrderPaid {
        static String code() {
            return "orderPaid";
        }
        static String name() {
            return "千牛商户支付订单";
        }
    }
}
